package router

import (
	"flag"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/apollo"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/config"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/errors"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/log"
)

// go admin配置有要求，不能给InitRouter传参，使用全局变量
// 在这里，直接使用flag解析自定义配置

type hxDingConfig struct {
	DebugErrorAlertURL string `yaml:"debugErrorAlertURL"`
	Keyword            string `yaml:"keyword"`
}

type StaticFileConfig struct {
	EmployeeImportTemplate string `yaml:"employeeImportTemplate"`
}

type hxAdminConfig struct {
	Common                        config.AppConfig `yaml:"common"`
	Static                        StaticFileConfig
	Ding                          hxDingConfig `yaml:"ding"`
	Log                           log.LogConfig
	Apollo                        apollo.Config
	ConstraintExecuteEngineConfig constraintExecuteEngineConfig
}

type constraintExecuteEngineConfig struct {
	Python3Path            string
	PythonScriptPrefixPath string
	TempDir                string
}

func (c *hxAdminConfig) validate() error {
	if err := c.Apollo.LoadAndValidate(); err != nil {
		return err
	}
	if err := c.Common.ValidateAndLoad(); err != nil {
		return err
	}
	return nil
}

func (c *hxAdminConfig) HostName() string {
	return c.Common.HostName
}

func (c *hxAdminConfig) HostIP() string {
	return c.Common.HostIP
}

var (
	flagConfigPath = "./config/settings.yml"
)

func parseHXConfigFromFlagFile() (hxAdminConfig, error) {
	var cfg hxAdminConfig
	if !flag.Parsed() {
		flag.Parse()
	}
	args := flag.Args()
	if len(args) > 1 {
		appendArgs := args[1:]
		for i, arg := range appendArgs {
			if arg == "-c" && i+1 < len(appendArgs) {
				flagConfigPath = appendArgs[i+1]
			}
		}
	}
	configPath := flagConfigPath
	log.Infof("[CONFIG]: use %s as config path", configPath)
	if errParse := config.CfgFromFile(configPath, &cfg); errParse != nil {
		return cfg, errors.Wrap(errParse, "parse to yml")
	}
	if errVal := cfg.validate(); errVal != nil {
		return cfg, errVal
	}
	return cfg, nil
}
