package router

import (
	"git.cestong.com.cn/cecf/cecf-golib/pkg/apollo"
	gin2 "git.cestong.com.cn/cecf/cecf-golib/pkg/gin"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/validate"
	"git.cestong.com.cn/cecf/config-center-server/pkg/controller"
	"github.com/gin-gonic/gin"
	jwt "github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth"
	"github.com/go-playground/validator/v10"
	"gorm.io/gorm"
)

//BuildRegisterCCApi 注册汇学业务相关路由
func BuildRegisterCCApi(db *gorm.DB, reqValidator *validator.Validate, apolloCli *apollo.HTTPClient, eeMap map[string]validate.ExecuteEngine) func(*gin.RouterGroup, *jwt.GinJWTMiddleware) {
	return func(r *gin.RouterGroup, authMid *jwt.GinJWTMiddleware) {
		appCtl := controller.NewAppController(db, reqValidator, apolloCli)
		appGroup := r.Group("/apps")
		appGroup.POST("", gin2.HandlerWrapper(appCtl.Create))
		appGroup.GET("", gin2.HandlerWrapper(appCtl.List))

		userConfigCtl := controller.NewUserConfigController(db, reqValidator)
		userConfigGroup := r.Group("/userconfig")
		{
			userConfigGroup.PUT("/:key", gin2.HandlerWrapper(userConfigCtl.Set))
			userConfigGroup.GET("", gin2.HandlerWrapper(userConfigCtl.UserAll))
		}

		configFileCtl := controller.NewConfigFileController(db, reqValidator, apolloCli)
		{
			appGroup.POST("/:appID/configfiles", gin2.HandlerWrapper(configFileCtl.Create))
		}
		configItemCtl := controller.NewConfigItemController(db, reqValidator, apolloCli)
		{
			appGroup.POST("/:appID/namespaces/:namespaceID/items", gin2.HandlerWrapper(configItemCtl.Create))
		}

		constraintCtl := controller.NewValueConstraintController(db, reqValidator, eeMap)
		constraintGroup := r.Group("/constraints")
		{
			constraintGroup.GET("", gin2.HandlerWrapper(constraintCtl.List))
			constraintGroup.POST("/value_test", gin2.HandlerWrapper(constraintCtl.ValueTest))
		}
	}
}
