package router

import (
	"net/url"
	"strconv"

	ccMiddleware "git.cestong.com.cn/cecf/cecf-golib/pkg/gin/middleware"
	log "git.cestong.com.cn/cecf/cecf-golib/pkg/log"
	"github.com/gin-gonic/gin"
	"github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth/user"
	"github.com/pkg/errors"
)

func buildNoRouteHandleFunc(backendURL string) (gin.HandlerFunc, error) {
	urlParsed, errParseURL := url.Parse(backendURL)
	if errParseURL != nil {
		return nil, errors.Wrapf(errParseURL, "%s not a valid URL", backendURL)
	}
	forwarderHandleFunc := ccMiddleware.ForwardToSingle(urlParsed, ccMiddleware.NewLogErrHandler(),
		urlAppendUserInfoRewriter(),
		ccMiddleware.SchemaHostRewrite(backendURL),
		ccMiddleware.RefererHeaderRewrite(backendURL))

	return forwarderHandleFunc, nil
}

func urlAppendUserInfoRewriter() gin.HandlerFunc {
	return func(c *gin.Context) {
		uid := user.GetUserId(c)
		q := c.Request.URL.Query()
		originQuery := q.Encode()
		q.Add("uid", strconv.Itoa(uid))
		c.Request.URL.RawQuery = q.Encode()
		newQuery := c.Request.URL.RawQuery
		log.Debugf("rewrite query %s=>%s", originQuery, newQuery)
	}
}
