package controller

import (
	"git.cestong.com.cn/cecf/cecf-golib/pkg/errors"
	gin2 "git.cestong.com.cn/cecf/cecf-golib/pkg/gin"
	"git.cestong.com.cn/cecf/cecf-golib/pkg/gin/middleware"
	"git.cestong.com.cn/cecf/config-center-server/pkg/model"
	"github.com/gin-gonic/gin"
	"github.com/go-playground/validator/v10"
	"gorm.io/gorm"
	"gorm.io/gorm/clause"
)

type UserConfigController struct {
	db  *gorm.DB
	val *validator.Validate
}

func NewUserConfigController(db *gorm.DB, val *validator.Validate) *UserConfigController {
	return &UserConfigController{db: db, val: val}
}

type SetUserConfigReqVO struct {
	Value string `json:"value"`
}

func (uc *UserConfigController) Set(c *gin.Context) (interface{}, error) {
	configKey := c.Param("key")
	var req SetUserConfigReqVO
	if errBind := c.ShouldBindJSON(&req); errBind != nil {
		return nil, errors.ErrBadRequest
	}
	var m model.UserConfigModel
	m.Value = req.Value
	m.Key = configKey
	adminID, findAdminID := middleware.GetAdminIDFromContext(c)
	if !findAdminID {
		errors.PanicWithString("必须提供adminIDFind中间件")
	}
	m.AdminID = adminID
	if errUpdate := uc.db.Clauses(clause.OnConflict{
		OnConstraint: "idx_adminID_Key",
		UpdateAll:    true,
	}).Create(&m).Error; errUpdate != nil {
		return nil, errUpdate
	}
	return gin2.SuccessGeneralVO(), nil
}

type UserAllConfigRespVO struct {
	Configs map[string]string
}

func (uc *UserConfigController) UserAll(c *gin.Context) (interface{}, error) {

	adminID, findAdminID := middleware.GetAdminIDFromContext(c)
	if !findAdminID {
		errors.PanicWithString("必须提供adminIDFind中间件")
	}
	var resp UserAllConfigRespVO
	var cfgList []model.UserConfigModel
	if errFind := uc.db.Where("admin_id=?", adminID).Find(&cfgList).Error; errFind != nil {
		return nil, errFind
	}
	resp.Configs = make(map[string]string, len(cfgList))
	for _, configModel := range cfgList {
		resp.Configs[configModel.Key] = configModel.Value
	}
	return resp, nil
}
